Reference
=========

----
Core
----

.. automodule:: tamarco.core.microservice
   :members:

Logging
-------

.. automodule:: tamarco.core.logging.logging
   :members:

Patterns
--------

.. automodule:: tamarco.core.patterns
   :members:

Settings
--------

.. automodule:: tamarco.core.settings.settings
   :members:

.. automodule:: tamarco.core.settings.settings_proxy
   :members:


---------
Resources
---------

.. automodule:: tamarco.resources.bases
   :members:


